@@ -43,8 +43,10 @@ fi
 EOF
 fi
 
-chroot . <<EOR 2>/dev/null
+# Chroot to insert the group in the possible --root target
+chroot . << EOR 2>/dev/null
 /usr/sbin/groupadd -g215 vboxusers 2> /dev/null
+EOR
 
 echo "********************************************************************************"
 echo "* Remember to run '/etc/rc.d/rc.vboxdrv setup' after install                   *"
@@ -54,14 +56,17 @@ echo "* /etc/rc.d/rc.vboxbridge and modify rc.local line to match your number of
 echo "* machines and the user running virtualbox.                                    *"
 echo "* rc.vboxbridge {start [number of virtual interfaces] [user] | stop}           *"
 echo "*                                                                              *"
-echo "* This package is the qt3 interface, if you want the new qt4 gui you have to   *"
-echo "* install the virtualbox-ose-qt4 package.                                      *"
+echo "* From version 2.2.0 there is only a qt4 gui, so no additional packages are    *"
+echo "* available anymore.                                                           *"
+echo "*                                                                              *"
+echo "* Legal notice: the guest additions included in this package are licensed      *"
+echo "* under the PUEL license, so you can't use these in commercial enviroments.    *"
 echo "********************************************************************************"
-( cd usr/bin ; rm -rf vboxheadless )
-( cd usr/bin ; ln -sf ../lib/virtualbox/VBox.sh vboxheadless )
-( cd usr/bin ; rm -rf vboxmanage )
-( cd usr/bin ; ln -sf ../lib/virtualbox/VBox.sh vboxmanage )
 ( cd usr/bin ; rm -rf vboxsdl )
 ( cd usr/bin ; ln -sf ../lib/virtualbox/VBox.sh vboxsdl )
-( cd usr/bin ; rm -rf virtualbox3 )
-( cd usr/bin ; ln -sf ../lib/virtualbox/VBox.sh virtualbox3 )
+( cd usr/bin ; rm -rf vboxheadless )
+( cd usr/bin ; ln -sf ../lib/virtualbox/VBox.sh vboxheadless )
+( cd usr/bin ; rm -rf virtualbox )
+( cd usr/bin ; ln -sf ../lib/virtualbox/VBox.sh virtualbox )
+( cd usr/bin ; rm -rf vboxmanage )
+( cd usr/bin ; ln -sf ../lib/virtualbox/VBox.sh vboxmanage )
